#
# spec file for package perl-ExtUtils-CppGuess
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name ExtUtils-CppGuess
Name:           perl-ExtUtils-CppGuess
Version:        0.270.0
Release:        bp160.1.8
%define cpan_version 0.27
License:        Artistic-1.0 OR GPL-1.0-or-later
Summary:        Guess C++ compiler and flags
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/E/ET/ETJ/%{cpan_name}-%{cpan_version}.tar.gz
Source1:        cpanspec.yml
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(Capture::Tiny)
BuildRequires:  perl(ExtUtils::CBuilder) >= 0.280231
BuildRequires:  perl(ExtUtils::ParseXS) >= 3.35
BuildRequires:  perl(Module::Build)
BuildRequires:  perl(Test::More) >= 0.88
Requires:       perl(Capture::Tiny)
Requires:       perl(ExtUtils::ParseXS) >= 3.35
Provides:       perl(ExtUtils::CppGuess) = %{version}
%undefine       __perllib_provides
%{perl_requires}
# MANUAL BEGIN
BuildRequires:  gcc-c++
# MANUAL END

%description
'ExtUtils::CppGuess' attempts to guess the system's C++ compiler that is
compatible with the C compiler that your perl was built with.

It can generate the necessary options to the Module::Build constructor or
to ExtUtils::MakeMaker's 'WriteMakefile' function.

%prep
%autosetup  -n %{cpan_name}-%{cpan_version}

%build
perl Makefile.PL INSTALLDIRS=vendor OPTIMIZE="%{optflags}"
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc Changes README

%changelog
* Fri Mar  8 2024 Tina Müller <tina.mueller@suse.com>
- Fix disabling of __perllib_provides
* Mon Nov 20 2023 Tina Müller <timueller+perl@suse.de>
- updated to 0.27
  see /usr/share/doc/packages/perl-ExtUtils-CppGuess/Changes
  0.27 2023-11-19
  - support C++20 and C++23 standards, and vendored version output - thanks @tonycoz
* Fri Apr 22 2022 Tina Müller <timueller+perl@suse.de>
- updated to 0.26
  see /usr/share/doc/packages/perl-ExtUtils-CppGuess/Changes
  0.26 2022-04-21
  - fix test-failure caused if CXX is set - thanks @hroncok for report
  0.25 2022-04-20
  - ignore environment variables CXXFLAGS, CXXLDFLAGS (#26) - thanks @hroncok for report
  0.24 2022-04-19
  - support environment variables CXX, CXXFLAGS, CXXLDFLAGS - thanks @dpryan79 for suggestion
* Tue Jun  1 2021 Tina Müller <timueller+perl@suse.de>
- updated to 0.23
  see /usr/share/doc/packages/perl-ExtUtils-CppGuess/Changes
  0.23 2021-05-31
  - added CI - thanks @zmughal
  - now recognises MacOS clang - thanks @xenu
  0.22 2021-05-29
  - Add C++ standard support flag detection - thanks @zmughal!
    See <https://github.com/tsee/extutils-cppguess/pull/24>.
* Fri Jan 24 2020 <timueller+perl@suse.de>
- updated to 0.21
  see /usr/share/doc/packages/perl-ExtUtils-CppGuess/Changes
* Mon Sep  2 2019 <timueller+perl@suse.de>
- updated to 0.20
  see /usr/share/doc/packages/perl-ExtUtils-CppGuess/Changes
  0.20    Sat 31 Aug 22:20:32 BST 2019
  - no link -lstdc++ if -static-libstdc++ - thanks @andygrundman
* Wed Apr  3 2019 Stephan Kulow <coolo@suse.com>
- updated to 0.19
  see /usr/share/doc/packages/perl-ExtUtils-CppGuess/Changes
  0.19    Mon  1 Apr 07:08:46 BST 2019
  - support clang on Perl 5.14-16 with ExtUtils::ParseXS >= 3.04_01 (yes, really)
  0.18    Sun 31 Mar 17:49:21 BST 2019
  - improve clang detection
  0.17    Sat 30 Mar 16:03:52 GMT 2019
  - support Sun Studio compiler family
  0.16    Sat 30 Mar 00:09:42 GMT 2019
  - test output more if no clue about compiler
  0.15    Fri 29 Mar 22:42:00 GMT 2019
  - iostream_fname, cpp_flavor_defs methods
  - add which actual compiler to use to generated MB and EUMM flags
  - make the test sensitive to whether to #include with a ".h"
  0.14	Mon 25 Mar 21:13:36 GMT 2019
  - add is_clang, unify OS-based detection
  0.13	Mon Mar 25 02:57:02 2019 +0000
  - repo tidied slightly
  - use Travis
  - add compiler_command, linker_flags
  - test all known configurations
  - inhale knowledge from Inline::CPP
* Thu Nov  9 2017 coolo@suse.com
- updated to 0.12
  see /usr/share/doc/packages/perl-ExtUtils-CppGuess/Changes
  0.12	Sat Oct 21 18:12:51 BST 2017
  - Fix tests on 5.26 without '.' in @INC (kentfredric)
* Tue Sep 15 2015 coolo@suse.com
- updated to 0.11
  see /usr/share/doc/packages/perl-ExtUtils-CppGuess/Changes
* Thu Sep 10 2015 coolo@suse.com
- updated to 0.10
  see /usr/share/doc/packages/perl-ExtUtils-CppGuess/Changes
  0.10   Tue Sep 11 21:15:30 MDT 2015
  - Config's ccflags must always be used. (bulk88)
* Tue Apr 14 2015 coolo@suse.com
- updated to 0.09
  see /usr/share/doc/packages/perl-ExtUtils-CppGuess/Changes
  0.09   Sat Apr 11 16:05:50 BST 2015
  - Convert to EUMM
  - Make tests divulge guessed options for better debugging
  0.08   Thu Jan 15 03:07:38 GMT 2015
  - Update metadata
* Sun Jun  8 2014 coolo@suse.com
- initial package 0.07
  * created by cpanspec 1.78.08
